# Keras Embedding Similarity

[![Travis](https://travis-ci.org/CyberZHG/keras-embed-sim.svg)](https://travis-ci.org/CyberZHG/keras-embed-sim)
[![Coverage](https://coveralls.io/repos/github/CyberZHG/keras-embed-sim/badge.svg?branch=master)](https://coveralls.io/github/CyberZHG/keras-embed-sim)
